package com.ruoyi.ems.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.ems.domain.PvSupplyH;

/**
 * 光伏并网计量-小时Service接口
 *
 * @author ruoyi
 * @date 2024-08-02
 */
public interface IPvSupplyHService
{
    /**
     * 查询光伏并网计量-小时
     *
     * @param id 光伏并网计量-小时主键
     * @return 光伏并网计量-小时
     */
     PvSupplyH selectPvSupplyHById(Long id);

    /**
     * 查询光伏并网计量-小时列表
     *
     * @param admEmsPvSupplyH 光伏并网计量-小时
     * @return 光伏并网计量-小时集合
     */
     List<PvSupplyH> selectPvSupplyHList(PvSupplyH admEmsPvSupplyH);


     List<PvSupplyH> selectAreaSupplyH(PvSupplyH admEmsPvSupplyH);

    List<Map<String, Object>> selectAreaSupplyHByThisDay(String areaCode);

    List<Map<String, Object>> selectAreaSupplyHByRefMonth(String areaCode);

    List<Map<String, Object>> selectAreaSupplyHByYear(String areaCode);
    /**
     * 新增光伏并网计量-小时
     *
     * @param admEmsPvSupplyH 光伏并网计量-小时
     * @return 结果
     */
     int insertPvSupplyH(PvSupplyH admEmsPvSupplyH);

    /**
     * 修改光伏并网计量-小时
     *
     * @param admEmsPvSupplyH 光伏并网计量-小时
     * @return 结果
     */
     int updatePvSupplyH(PvSupplyH admEmsPvSupplyH);

    /**
     * 批量删除光伏并网计量-小时
     *
     * @param ids 需要删除的光伏并网计量-小时主键集合
     * @return 结果
     */
     int deletePvSupplyHByIds(Long[] ids);

    /**
     * 删除光伏并网计量-小时信息
     *
     * @param id 光伏并网计量-小时主键
     * @return 结果
     */
     int deletePvSupplyHById(Long id);
}
